==> aws-java-sdk-osgi-1.9.40-sources.jar: com/amazonaws/services/importexport/model/transform/GetShippingLabelResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.importexport.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.importexport.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Get Shipping Label Result StAX Unmarshaller
 */
public class GetShippingLabelResultStaxUnmarshaller implements Unmarshaller<GetShippingLabelResult, StaxUnmarshallerContext> {

    public GetShippingLabelResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        GetShippingLabelResult getShippingLabelResult = new GetShippingLabelResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return getShippingLabelResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("ShippingLabelURL", targetDepth)) {
                    getShippingLabelResult.setShippingLabelURL(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Warning", targetDepth)) {
                    getShippingLabelResult.setWarning(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getShippingLabelResult;
                }
            }
        }
    }

    private static GetShippingLabelResultStaxUnmarshaller instance;
    public static GetShippingLabelResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new GetShippingLabelResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-osgi-1.10.25-sources.jar: com/amazonaws/services/importexport/model/transform/GetShippingLabelResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.importexport.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.importexport.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * GetShippingLabelResult StAX Unmarshaller
 */
public class GetShippingLabelResultStaxUnmarshaller implements
        Unmarshaller<GetShippingLabelResult, StaxUnmarshallerContext> {

    public GetShippingLabelResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        GetShippingLabelResult getShippingLabelResult = new GetShippingLabelResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return getShippingLabelResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("ShippingLabelURL", targetDepth)) {
                    getShippingLabelResult
                            .setShippingLabelURL(StringStaxUnmarshaller
                                    .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("Warning", targetDepth)) {
                    getShippingLabelResult.setWarning(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getShippingLabelResult;
                }
            }
        }
    }

    private static GetShippingLabelResultStaxUnmarshaller instance;

    public static GetShippingLabelResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetShippingLabelResultStaxUnmarshaller();
        return instance;
    }
}
